# Installation

Visisipy can be installed through `pip`:

```bash
pip install visisipy
```

To use Torch for GPU-accelerated ray tracing, you need to install the `torch` package:

```bash
pip install visisipy[torch]
```

GPU acceleration is only available for the [Optiland backend](backend.ipynb).